aboutsummaryrefslogtreecommitdiff
path: root/usr.sbin
diff options
context:
space:
mode:
authorElyes HAOUAS <ehaouas@noos.fr>2021-10-06 15:32:15 +0000
committerWarner Losh <imp@FreeBSD.org>2021-11-19 06:05:32 +0000
commit9097ac9af4144187d080cf6c796c50d777e517b1 (patch)
treefec92e868d4ecb03eb9a0970b14952abe74b3620 /usr.sbin
parent872d50a5d8fca234823385c0a134cd0da0f4477a (diff)
downloadsrc-9097ac9af4144187d080cf6c796c50d777e517b1.tar.gz
src-9097ac9af4144187d080cf6c796c50d777e517b1.zip
Fix typo on "Celsius"
"Celcius" --> "Celsius" Signed-off-by: Elyes HAOUAS <ehaouas@noos.fr> Pull Request: https://github.com/freebsd/freebsd-src/pull/551/files
Diffstat (limited to 'usr.sbin')
-rw-r--r--usr.sbin/prometheus_sysctl_exporter/prometheus_sysctl_exporter.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr.sbin/prometheus_sysctl_exporter/prometheus_sysctl_exporter.c b/usr.sbin/prometheus_sysctl_exporter/prometheus_sysctl_exporter.c
index 25e60f5dddbe..9d50c3e58750 100644
--- a/usr.sbin/prometheus_sysctl_exporter/prometheus_sysctl_exporter.c
+++ b/usr.sbin/prometheus_sysctl_exporter/prometheus_sysctl_exporter.c
@@ -300,7 +300,7 @@ oid_get_value(const struct oid *o, const struct oidformat *of,
return (false);
}
/* Convert temperatures from decikelvin to degrees Celcius. */
if (oidformat_is_temperature(of)) {
double v;
int e;
@@ -403,7 +403,7 @@ oid_get_metric(const struct oidname *on, const struct oidformat *of,
label += strlen(label) + 1;
}
if (oidformat_is_temperature(of))
- strlcat(metric, "_celcius", mlen);
+ strlcat(metric, "_celsius", mlen);
else if (oidformat_is_timeval(of))
strlcat(metric, "_seconds", mlen);
@@ -300,7 +300,7 @@ oid_get_value(const struct oid *o, const struct oidformat *of,
return (false);
}
- /* Convert temperatures from decikelvin to degrees Celcius. */
+ /* Convert temperatures from decikelvin to degrees Celsius. */
if (oidformat_is_temperature(of)) {
double v;